@@ -2,7 +2,7 @@
 #' @method print PlackettLuce
 #' @export
 print.PlackettLuce <- function(x,
-                               digits = max(3, getOption("digits") - 3),
+                               digits = max(3L, getOption("digits") - 3L),
                                ...) {
     cat(format_call(x$call), sep = "\n")
 
@@ -14,14 +14,14 @@ print.PlackettLuce <- function(x,
 }
 
 format_call <- function(x){
-    w <- getOption("width") - 6
+    w <- getOption("width") - 6L
     string <- deparse(x, width.cutoff = w)
-    string[1] <- paste("Call:", string[1])
+    string[1L] <- paste("Call:", string[1L])
     # minimum width in deparse is 20
     while (w >= 21 & max(nchar(string)) > getOption("width")){
-        w <- w - 1
+        w <- w - 1L
         string <- deparse(x, width.cutoff = w)
-        string[1] <- paste("Call:", string[1])
+        string[1L] <- paste("Call:", string[1L])
     }
     string
 }
