@@ -1,4 +1,11 @@
-## ----setup, include = FALSE------------------------------------------------
+## ----output, include = FALSE--------------------------------------------------
+output <- if (requireNamespace("BiocStyle", quietly = TRUE)) {
+  BiocStyle::html_document
+} else if (requireNamespace("bookdown", quietly = TRUE)) {
+  bookdown::html_document2
+} else html_document
+
+## ----setup, include = FALSE---------------------------------------------------
 library(knitr)
 eval_all <- FALSE # evaluate all timings and pltree?
 extra <- requireNamespace("kableExtra")
@@ -8,7 +15,7 @@ if (!identical(table.format, "latex")) table.format <- "html"
 opts_knit$set(knitr.table.format = table.format)
 opts_chunk$set(message = FALSE)
 
-## ---- echo = FALSE---------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 as.matrix(data.frame(choice = c(1, 1, 1, 2, 2),
                      `item 1` = c(1, 0, 0, 1, 0),
                      `item 2` = c(0, 1, 0, 0, 1),
@@ -16,15 +23,15 @@ as.matrix(data.frame(choice = c(1, 1, 1, 2, 2),
                      count = c(0, 0, 1, 1, 0), check.names = FALSE))
 
 
-## ----soc, eval = eval_all, echo = FALSE------------------------------------
+## ----soc, eval = eval_all, echo = FALSE---------------------------------------
 #  library(PlackettLuce)
 #  # read in example data sets
-#  preflib <- "http://www.preflib.org/data/election/"
+#  preflib <- "https://www.preflib.org/data/election/"
 #  netflix <- read.soc(file.path(preflib, "netflix/ED-00004-00000101.soc"))
 #  tshirt <- read.soc(file.path(preflib, "shirt/ED-00012-00000001.soc"))
 #  sushi <- read.soc(file.path(preflib, "sushi/ED-00014-00000001.soc"))
 
-## ----wrappers, eval = eval_all, echo = FALSE-------------------------------
+## ----wrappers, eval = eval_all, echo = FALSE----------------------------------
 #  pl <- function(dat, ...){
 #      # convert ordered items to ranking
 #      R <- as.rankings(dat[,-1], "ordering")
@@ -91,7 +98,7 @@ as.matrix(data.frame(choice = c(1, 1, 1, 2, 2),
 #  sushi_timings <- timings(sushi, 5,
 #                           fun = c("pl", "hyper2", "plmix", "statrank"))
 
-## ----save-timings, echo = FALSE--------------------------------------------
+## ----save-timings, echo = FALSE-----------------------------------------------
 if (eval_all){
     saveRDS(netflix_timings, "netflix_timings.rds", version = 2)
     saveRDS(tshirt_timings, "tshirt_timings.rds", version = 2)
@@ -102,7 +109,7 @@ if (eval_all){
     sushi_timings <- readRDS("sushi_timings.rds")
 }
 
-## ----data-features, echo = FALSE-------------------------------------------
+## ----data-features, echo = FALSE----------------------------------------------
 features <- cbind(c(1256, 30, 5000),
                   c(24, 30, 4926),
                   c(4, 11, 10))
@@ -115,7 +122,7 @@ if (extra){
     kableExtra::kable_styling(kab)
 } else kab
 
-## ----timings-kable, echo = FALSE, results = "asis"-------------------------
+## ----timings-kable, echo = FALSE, results = "asis"----------------------------
 res <- data.frame(netflix = round(unlist(netflix_timings), 3),
                   tshirt = format(unlist(tshirt_timings), 3),
                   sushi = round(unlist(sushi_timings), 3),
@@ -145,14 +152,14 @@ if (extra){
 #  nascar <- cbind(n = 1, Data.Nascar)
 #  nascar_timings <- timings(nascar, fun = c("pl", "hyper2"))
 
-## ----save-timings-sub, echo = FALSE----------------------------------------
+## ----save-timings-sub, echo = FALSE-------------------------------------------
 if (eval_all){
     saveRDS(nascar_timings, "nascar_timings.rds", version = 2)
 } else {
     nascar_timings <- readRDS("nascar_timings.rds")
 }
 
-## ----nascar, echo = FALSE--------------------------------------------------
+## ----nascar, echo = FALSE-----------------------------------------------------
 res <- round(unlist(nascar_timings)[c("pl", "hyper2")], 3)
 res <- data.frame(Rankings = 36,
                   Items = 83,
@@ -168,7 +175,7 @@ if (requireNamespace("kableExtra")){
                                         "Time elapsed (s)" = 2))
 } else kab
 
-## ----package-summary, echo = FALSE-----------------------------------------
+## ----package-summary, echo = FALSE--------------------------------------------
 tab <- data.frame(Feature = c("Inference", "Disconnected networks",
                               "Ties", "Teams", "Heterogenous case"),
                   PlackettLuce = c("Frequentist", "Yes", "Yes", "No", "Trees"),
@@ -182,11 +189,11 @@ if (requireNamespace("kableExtra")){
     kableExtra::kable_styling(kab)
 } else kab
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(PlackettLuce)
 head(pudding)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 i_wins <- data.frame(Winner = pudding$i, Loser = pudding$j)
 j_wins <- data.frame(Winner = pudding$j, Loser = pudding$i)
 if (getRversion() < "3.6.0"){
@@ -199,36 +206,36 @@ if (getRversion() < "3.6.0"){
 }
 head(ties, 2)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 R <- as.rankings(rbind(i_wins, j_wins, ties),
                  input = "orderings")
 head(R, 2)
 tail(R, 2)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 head(unclass(R), 2)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 w <- unlist(pudding[c("w_ij", "w_ji", "t_ij")])
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 mod <- PlackettLuce(R, weights = w, npseudo = 0, maxit = 7)
 coef(mod, log = FALSE)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 summary(mod)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 summary(mod, ref = NULL)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 qv <- qvcalc(mod)
 summary(qv)
 
 ## ----pudding-qv, fig.cap = "Worth of brands of chocolate pudding. Intervals based on quasi-standard errors."----
 plot(qv, xlab = "Brand of pudding", ylab = "Worth (log)", main = NULL)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 R <- matrix(c(1, 2, 0, 0,
               2, 0, 1, 0,
               1, 0, 0, 2,
@@ -237,7 +244,7 @@ R <- matrix(c(1, 2, 0, 0,
             dimnames = list(NULL, LETTERS[1:4]))
 R <- as.rankings(R)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 A <- adjacency(R)
 A
 
@@ -246,50 +253,50 @@ library(igraph)
 net <- graph_from_adjacency_matrix(A)
 plot(net, edge.arrow.size = 0.5, vertex.size = 30)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 connectivity(A)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 R2 <- R[, -4]
 R2
 mod <- PlackettLuce(R2, npseudo = 0)
 summary(mod)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 mod2 <- PlackettLuce(R)
 coef(mod2)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 data(nascar)
 nascar[1:2, ]
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 R <- as.rankings(nascar, input = "orderings", items = attr(nascar, "drivers"))
 R[1:2]
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 keep <- seq_len(83)
 R2 <- R[, keep]
 mod <- PlackettLuce(R2, npseudo = 0)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 avRank <- apply(R, 2, function(x) mean(x[x > 0]))
 coefs <- round(coef(mod)[order(avRank[keep])], 2)
 head(coefs, 3)
 tail(coefs, 3)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 mod2 <- PlackettLuce(R)
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 coefs2 <- round(coef(mod2), 2)
 coefs2[names(coefs)[1:3]]
 coefs2[names(coefs)[81:83]]
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 coefs2[84:87]
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 coef(summary(mod2))[84:87,]
 
 ## ----nascar-qv, fig.cap = "Ability of drivers based on NASCAR 2002 season. Intervals based on quasi-standard errors.", fig.wide = TRUE----
@@ -299,21 +306,21 @@ plot(qv, xlab = NULL, ylab = "Ability (log)", main = NULL,
      xaxt="n", xlim = c(3, 85))
 axis(1, at = seq_len(87), labels = rownames(qv$qvframe), las = 2, cex.axis = 0.6)
 
-## ----beans-preparation, results = "hide"-----------------------------------
+## ----beans-preparation, results = "hide"--------------------------------------
 example("beans", package = "PlackettLuce")
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 n <- nrow(beans)
 G <- group(R, index = rep(seq_len(n), 4))
 format(head(G, 2), width = 50)
 
-## ----pltree, eval = eval_all-----------------------------------------------
+## ----pltree, eval = eval_all--------------------------------------------------
 #  beans$year <- factor(beans$year)
 #  tree <- pltree(G ~ ., data = beans[c("season", "year", "maxTN")],
 #                 minsize = 0.05*n, maxdepth = 3)
 #  tree
 
-## ----save-tree, echo = FALSE-----------------------------------------------
+## ----save-tree, echo = FALSE--------------------------------------------------
 if (eval_all){
     saveRDS(tree, "pltree.rds", version = 2)
 } else {
@@ -323,19 +330,19 @@ if (eval_all){
 ## ----plot-pltree, fig.wide = TRUE, fig.cap = "Worth parameters for the ten trial varieties and the local variety for each node in the Plackett-Luce tree. Varieties are 1: ALS 0532-6, 2: BRT 103-182, 3: INTA Centro Sur, 4: INTA Ferroso, 5: INTA Matagalpa, 6: INTA Precoz, 7: INTA Rojo, 8: INTA Sequia, 9: Local, 10: PM2 Don Rey, 11: SJC 730-79."----
 plot(tree, names = FALSE, abbreviate = 2)
 
-## ----show-soc--------------------------------------------------------------
+## ----show-soc-----------------------------------------------------------------
 
-## ----soc, eval = FALSE-----------------------------------------------------
+## ----soc, eval = FALSE--------------------------------------------------------
 #  library(PlackettLuce)
 #  # read in example data sets
-#  preflib <- "http://www.preflib.org/data/election/"
+#  preflib <- "https://www.preflib.org/data/election/"
 #  netflix <- read.soc(file.path(preflib, "netflix/ED-00004-00000101.soc"))
 #  tshirt <- read.soc(file.path(preflib, "shirt/ED-00012-00000001.soc"))
 #  sushi <- read.soc(file.path(preflib, "sushi/ED-00014-00000001.soc"))
 
-## ----chunk2----------------------------------------------------------------
+## ----chunk2-------------------------------------------------------------------
 
-## ----wrappers, eval = FALSE------------------------------------------------
+## ----wrappers, eval = FALSE---------------------------------------------------
 #  pl <- function(dat, ...){
 #      # convert ordered items to ranking
 #      R <- as.rankings(dat[,-1], "ordering")
@@ -384,9 +391,9 @@ plot(tree, names = FALSE, abbreviate = 2)
 #      res
 #  }
 
-## ----chunk2----------------------------------------------------------------
+## ----chunk2-------------------------------------------------------------------
 
-## ----timings, eval = FALSE-------------------------------------------------
+## ----timings, eval = FALSE----------------------------------------------------
 #  timings <- function(dat, iter = NULL,
 #                      fun = c("pl", "hyper2", "plmix", "pmr", "statrank")){
 #      res <- list()
@@ -404,31 +411,31 @@ plot(tree, names = FALSE, abbreviate = 2)
 #  sushi_timings <- timings(sushi, 5,
 #                           fun = c("pl", "hyper2", "plmix", "statrank"))
 
-## ----beans-1---------------------------------------------------------------
+## ----beans-1------------------------------------------------------------------
 data(beans)
 head(beans[c("best", "worst")], 2)
 
-## ----beans-2---------------------------------------------------------------
+## ----beans-2------------------------------------------------------------------
 beans$middle <- complete(beans[c("best", "worst")],
                          items = c("A", "B", "C"))
 head(beans[c("best", "middle", "worst")], 2)
 
-## ----beans-3---------------------------------------------------------------
+## ----beans-3------------------------------------------------------------------
 head(beans[c("variety_a", "variety_b", "variety_c")], 2)
 
-## ----beans-4---------------------------------------------------------------
+## ----beans-4------------------------------------------------------------------
 order3 <- decode(beans[c("best", "middle", "worst")],
                  items = beans[c("variety_a", "variety_b", "variety_c")],
                  code = c("A", "B", "C"))
 
-## ----beans-6---------------------------------------------------------------
+## ----beans-6------------------------------------------------------------------
 head(beans[c("var_a", "var_b", "var_c")], 2)
 
-## ----beans-7---------------------------------------------------------------
+## ----beans-7------------------------------------------------------------------
 trial_variety <- unlist(beans[c("variety_a", "variety_b", "variety_c")])
 outcome <- unlist(beans[c("var_a", "var_b", "var_c")])
 
-## --------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 order2 <- data.frame(Winner = ifelse(outcome == "Worse",
                                      "Local", trial_variety),
                      Loser = ifelse(outcome == "Worse",
@@ -436,7 +443,7 @@ order2 <- data.frame(Winner = ifelse(outcome == "Worse",
                      stringsAsFactors = FALSE, row.names = NULL)
 head(order2, 2)
 
-## ----beans-8---------------------------------------------------------------
+## ----beans-8------------------------------------------------------------------
 R <- rbind(as.rankings(order3, input = "ordering"),
            as.rankings(order2, input = "ordering"))
 head(R)
